@@ -46,7 +46,7 @@ import java.util.Locale;
  * Bundles the Javadoc documentation for <code>main Java code</code> in an <b>NON aggregator</b> project into
  * a jar using the standard <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>.
  *
- * @version $Id: JavadocJar.java 1672205 2015-04-08 22:10:02Z khmarbaise $
+ * @version $Id: JavadocJar.java 1720689 2015-12-17 22:33:10Z michaelo $
  * @since 2.0
  */
 @Mojo( name = "jar", defaultPhase = LifecyclePhase.PACKAGE, requiresDependencyResolution = ResolutionScope.COMPILE,
@@ -130,7 +130,7 @@ public class JavadocJar
      * @since 2.5
      */
     @Parameter
-    private MavenArchiveConfiguration archive = new MavenArchiveConfiguration();
+    private MavenArchiveConfiguration archive = new JavadocArchiveConfiguration();
 
     /**
      * Path to the default MANIFEST file to use. It will be used if
@@ -295,8 +295,6 @@ public class JavadocJar
 
         try
         {
-            // we don't want Maven stuff
-            archive.setAddMavenDescriptor( false );
             archiver.createArchive( session, project, archive );
         }
         catch ( ManifestException e )
