@@ -95,7 +95,7 @@ import java.util.regex.PatternSyntaxException;
  * Set of utilities methods for Javadoc.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: JavadocUtil.java 1672205 2015-04-08 22:10:02Z khmarbaise $
+ * @version $Id: JavadocUtil.java 1742353 2016-05-05 03:22:53Z schulte $
  * @since 2.4
  */
 public class JavadocUtil
@@ -654,7 +654,7 @@ public class JavadocUtil
      * @param output for 'javadoc -J-version'
      * @return the version of the javadoc for the output.
      * @throws PatternSyntaxException if the output doesn't match with the output pattern
-     * <tt>(?s).*?([0-9]+\\.[0-9]+)(\\.([0-9]+))?.*</tt>.
+     * <tt>(?s).*?[^a-zA-Z]([0-9]+\\.?[0-9]*)(\\.([0-9]+))?.*</tt>.
      * @throws IllegalArgumentException if the output is null
      */
     protected static float parseJavadocVersion( String output )
@@ -665,7 +665,7 @@ public class JavadocUtil
             throw new IllegalArgumentException( "The output could not be null." );
         }
 
-        Pattern pattern = Pattern.compile( "(?s).*?([0-9]+\\.[0-9]+)(\\.([0-9]+))?.*" );
+        Pattern pattern = Pattern.compile( "(?s).*?[^a-zA-Z]([0-9]+\\.?[0-9]*)(\\.([0-9]+))?.*" );
 
         Matcher matcher = pattern.matcher( output );
         if ( !matcher.matches() )
@@ -780,8 +780,10 @@ public class JavadocUtil
         try
         {
             osw = new OutputStreamWriter( ost, charsetName );
+            osw.close();
+            osw = null;
         }
-        catch ( UnsupportedEncodingException exc )
+        catch ( IOException exc )
         {
             return false;
         }
@@ -895,29 +897,35 @@ public class JavadocUtil
             throw new IOException( "The url could not be null." );
         }
 
-        InputStream is = url.openStream();
-        if ( is == null )
-        {
-            throw new IOException( "The resource " + url + " doesn't exists." );
-        }
-
         if ( !file.getParentFile().exists() )
         {
             file.getParentFile().mkdirs();
         }
 
-        OutputStream os = null;
+        InputStream in = null;
+        OutputStream out = null;
         try
         {
-            os = new FileOutputStream( file );
+            in = url.openStream();
 
-            IOUtil.copy( is, os );
+            if ( in == null )
+            {
+                throw new IOException( "The resource " + url + " doesn't exists." );
+            }
+
+            out = new FileOutputStream( file );
+
+            IOUtil.copy( in, out );
+
+            out.close();
+            out = null;
+            in.close();
+            in = null;
         }
         finally
         {
-            IOUtil.close( is );
-
-            IOUtil.close( os );
+            IOUtil.close( in );
+            IOUtil.close( out );
         }
     }
 
@@ -1150,8 +1158,9 @@ public class JavadocUtil
         try
         {
             jarStream = new JarInputStream( new FileInputStream( jarFile ) );
-            JarEntry jarEntry = jarStream.getNextJarEntry();
-            while ( jarEntry != null )
+
+            for ( JarEntry jarEntry = jarStream.getNextJarEntry(); jarEntry != null;
+                  jarEntry = jarStream.getNextJarEntry() )
             {
                 if ( jarEntry.getName().toLowerCase( Locale.ENGLISH ).endsWith( ".class" ) )
                 {
@@ -1161,8 +1170,10 @@ public class JavadocUtil
                 }
 
                 jarStream.closeEntry();
-                jarEntry = jarStream.getNextJarEntry();
             }
+
+            jarStream.close();
+            jarStream = null;
         }
         finally
         {
@@ -1731,8 +1742,7 @@ public class JavadocUtil
 
             if ( validateContent )
             {
-                String line;
-                while ( ( line = reader.readLine() ) != null )
+                for ( String line = reader.readLine(); line != null; line = reader.readLine() )
                 {
                     if ( !isValidPackageName( line ) )
                     {
@@ -1741,6 +1751,9 @@ public class JavadocUtil
                 }
             }
 
+            reader.close();
+            reader = null;
+
             return true;
         }
         finally
