@@ -46,7 +46,7 @@ import com.thoughtworks.qdox.model.JavaMethod;
 
 /**
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: FixJavadocMojoTest.java 1579989 2014-03-21 17:30:56Z aheritier $
+ * @version $Id: FixJavadocMojoTest.java 1742353 2016-05-05 03:22:53Z schulte $
  */
 public class FixJavadocMojoTest
     extends AbstractMojoTestCase
@@ -721,7 +721,10 @@ public class FixJavadocMojoTest
         try
         {
             fileReader = ReaderFactory.newReader( file, "UTF-8" );
-            return IOUtil.toString( fileReader );
+            final String content = IOUtil.toString( fileReader );
+            fileReader.close();
+            fileReader = null;
+            return content;
         }
         finally
         {
